@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Manipulate the position of a note in a scale
 
-our $VERSION = '0.0502';
+our $VERSION = '0.0503';
 
 use Carp;
 use Moo;
@@ -49,25 +49,25 @@ has verbose => (
 sub get_offset {
     my ( $self, %args ) = @_;
 
-    my $note_name   = $args{note_name};
-    my $note_format = $args{note_format} || $self->note_format;
-    my $offset      = $args{offset} || $self->offset;
+    my $name   = $args{note_name};
+    my $format = $args{note_format} || $self->note_format;
+    my $offset = $args{offset} || $self->offset;
 
     croak 'note_name, note_format or offset not provided'
-        unless $note_name || $note_format || $offset;
+        unless $name || $format || $offset;
 
     my $rev;  # Going in reverse?
 
-    my $note = Music::Note->new( $note_name, $note_format );
+    my $note = Music::Note->new( $name, $format );
 
     my $equiv;
     if ( $note->format('isobase') =~ /b/ || $note->format('isobase') =~ /#/ ) {
-        $equiv = Music::Note->new( $note_name, $note_format );
+        $equiv = Music::Note->new( $name, $format );
         $equiv->en_eq( $note->format('isobase') =~ /b/ ? 'sharp' : 'flat' );
     }
 
     warn sprintf "Given note: %s, ISO: %s/%s, Offset: %d\n",
-        $note_name, $note->format('ISO'), ( $equiv ? $equiv->format('ISO') : '' ), $offset
+        $name, $note->format('ISO'), ( $equiv ? $equiv->format('ISO') : '' ), $offset
         if $self->verbose;
 
     my @scale = get_scale_notes( $self->scale_note, $self->scale_name );
@@ -108,7 +108,7 @@ sub get_offset {
     $note = Music::Note->new( $scale[ $offset % @scale ] . $octave, 'ISO' );
 
     warn sprintf "\tNew offset: %d, ISO: %s, Formatted: %s\n",
-        $offset, $note->format('ISO'), $note->format($note_format)
+        $offset, $note->format('ISO'), $note->format($format)
         if $self->verbose;
 
     return $note;
@@ -128,7 +128,7 @@ Music::ScaleNote - Manipulate the position of a note in a scale
 
 =head1 VERSION
 
-version 0.0502
+version 0.0503
 
 =head1 SYNOPSIS
 
@@ -162,7 +162,7 @@ For offset C<-1>, C<A#3> is returned.
 
 =head2 scale_note
 
-This is the name of the note (with no octave) that starts the given
+This is the isobase name of the note (with no octave) that starts the
 scale.
 
 Default: C<C>
@@ -173,21 +173,24 @@ Examples: C<G#>, C<Eb>
 
 This is the name of the scale to use.
 
-Please see L<Music::Scales/SCALES> for the possible names.
+Please see L<Music::Scales/SCALES> for the possibilities.
 
 Default: C<major>
 
 =head2 note_format
 
-The format as given by L<Music::Note/STYLES>.  If given in the constructor, this
-is used as the default in the B<get_offset> method.
+The format as given by L<Music::Note/STYLES>.  If set in the
+constructor, this is used in the B<get_offset> method.
 
 Default: C<ISO>
 
+This is used in conjunction with the B<note_name> to determine the
+L<Music::Note> in the B<get_offset> method.
+
 =head2 offset
 
-The integer offset of a new scale position.  If given in the constructor, this
-is used as the default in the B<get_offset> method.
+The integer offset of a new scale position.  If set in the
+constructor, this is used in the B<get_offset> method.
 
 Default: C<1>
 
